@@ -23,21 +23,20 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 
 """ 
-Mother is a python module that hides SQL syntax and gives you a set 
-of intelligent classes and methods. With `intelligent` we mean the 
-capability of self-adaption, understanding various situations.
-Mother could be considered as a Object Relational Mapper with a strong 
-introspection. 
-In fact, configuration files, tables, fields and keys declarations are 
-not needed, because Mother knows the database structure herself.
-
-Mother works with PostgreSQL and, for now, only this database is 
-supported: in fact, the introspective nature of Mother is based on 
-postgres meta queries.
+Mother is a python module that hides SQL syntax and gives 
+you a set of intelligent classes and methods. With `intelligent` 
+we mean the capability of self-adaption, understanding various 
+situations.
+Mother could be considered as a Object Relational Mapper with a 
+strong introspection. 
+In fact, configuration files, tables, fields and keys declarations 
+are not needed, because Mother knows the database structure herself.
+Mother works with PostgreSQL and SQlite.
+BSD License.
 """
 
-__all__     = ['speaker', 'dbda', 'commons', 'eccez', 'mothers']
-__version__ = '0.5.5'
+__all__     = ['speaker', 'abdbda', 'commons', 'eccez', 'mothers']
+__version__ = '0.6 0-r1'
 __author__  = 'Federico Tomassini aka efphe'
 __contact__ = 'Report Bugs and Ideas to users@dbmother.org '\
               '(need to subscribe) or to efphe@dbmother.org'
