@@ -4,12 +4,11 @@
 ##      -> Commented values are default values <-
 #
 
-  #                 #
-  ###             ### 
-  #  MOTHER TUNING  #
-  ###             ###
-  #                 #
-
+  #              #
+  ###          ### 
+  #  MOTHER MAP  #
+  ###          ###
+  #              #
 
 #
 ##
@@ -27,69 +26,31 @@
 
 MOTHER_MAP= '/my/mother/map'
 
-#
-##
-# By default, Mother uses OIDs.
-# This will be changed when postgres-8.2.3 will be the 
-# most diffused version of postgres.
-#
-# OIDs have been deprecated with postgres-8.1, but 
-# they are completely working and supported.
-#
-# Anyway, it's possible to avoid OIDs, but to do that
-# a postgres version >= 8.2.3 is needed.
-#
-# If you run a postgres version >= 8.2.3, set the 
-# following to False. It's all.
-#
-# If you run a version < 8.1, use True. It's all.
-#
-# Otherwise, you HAVE to set the following to True
-# and your tables have to be created WITH OIDS:
-#
-#   CREATE TABLE my_table ( ... ) WITH OIDS;
-#
-# If you decide to upgrade postgres to 8.2.3, it's 
-# safe to change this switch to False.
-# If you decide to upgrade to 8.1, make sure that 
-# your tables use OIDs.
-#
-# If you use a postgres version < 8.2.3 and you don't
-# want to use OIDs, choose another ORM, but forget
-# the Mother introspection ;)
-##
-#
 
-# MOTHER_OIDS= True
-
-
-  #                    #
-  ###                ### 
-  #  DATABASE ADAPTER  #
-  ###                ###
-  #                    #
+  #               #
+  ##             ##
+  ### DB ENGINE ###
+  ##             ##
+  #               #
 
 #
 ##
-### DB info
+# Mother supports different db.
+# Choose here between:
+#
+#   - DB_ENGINE_PGRES
+#   - DB_ENGINE_SQLITE
 ##
 #
 
-# If DB_HOST is None, Unix Sockets will be used (Unix only)
-# In this case, DB_PORT is ignored.
-
-DB_HOST= 'localhost'
-DB_NAME= "universe"
-DB_USER= "space_man"
-DB_PASSWD= "space_password"
-# DB_PORT= 5432
+# DB_ENGINE= DB_ENGINE_PGRES
 
 
-#
-##
-### Threaded Environment
-##
-#
+  #                 #
+  ##               ##
+  ### MOTHER POOL ###
+  ##               ##
+  #                 #
 
 #
 ##
@@ -125,8 +86,8 @@ DB_PASSWD= "space_password"
 # The goal is to prevent queries confusion and transactions
 # bugs.
 #
-# Note that the following variable is ignored if DB_POOL is
-# False.
+# Note that the following variable is considered True if 
+# DB_POOL is False.
 ##
 #
 
@@ -148,14 +109,13 @@ DB_PASSWD= "space_password"
 #
 # This is not always True: it depends also on which type
 # of pool will be choosed. Anyway, this behaviour is the
-# default behaviour.
+# default behaviour. See the next sections.
 ## 
 #
 
 # DB_POOL_MIN= 4
 # DB_POOL_MAX= 10
 
-
 #
 ##
 ### Timeout
@@ -251,7 +211,8 @@ DB_PASSWD= "space_password"
 # Mother will be use.
 #
 # Note: the name of sessions is *very* useful 
-# when reading logs :)
+# when reading logs, so it's a good idea to name
+# your sessions.
 ##
 #
 
@@ -371,3 +332,79 @@ DB_PASSWD= "space_password"
 # LOG_SMTP_RCPT=    'destination@debug.debug'
 # LOG_SMTP_SUBJECT= 'debug message from Mother'
 
+
+  #              #
+  ##            ##
+  ### POSTGRES ###
+  ##            ##
+  #              #
+
+
+# if sqlite is used, just skip this section
+
+#
+##  Postgresql Oids
+#
+# By default, Mother uses OIDs.
+# This will be changed when postgres-8.2.3 will be the 
+# most diffused version of postgres.
+#
+# OIDs have been deprecated with postgres-8.1, but 
+# they are completely working and supported.
+#
+# Anyway, it's possible to avoid OIDs, but to do that
+# a postgres version >= 8.2.3 is needed.
+#
+# If you run a postgres version >= 8.2.3, set the 
+# following to False. It's all.
+#
+# If you run a version < 8.1, use True. It's all.
+#
+# Otherwise, you HAVE to set the following to True
+# and your tables have to be created WITH OIDS:
+#
+#   CREATE TABLE my_table ( ... ) WITH OIDS;
+#
+# If you decide to upgrade postgres to 8.2.3, it's 
+# safe to change this switch to False.
+# If you decide to upgrade to 8.1, make sure that 
+# your tables use OIDs.
+#
+# If you use a postgres version < 8.2.3 and you don't
+# want to use OIDs, choose another ORM, but forget
+# the Mother introspection ;)
+##
+#
+
+# MOTHER_OIDS= True
+
+#
+## DB info
+#
+# If DB_HOST is None, Unix Sockets will be used (Unix only)
+# In this case, DB_PORT is ignored.
+##
+#
+
+DB_HOST= 'localhost'
+DB_NAME= "universe"
+DB_USER= "space_man"
+DB_PASSWD= "space_password"
+# DB_PORT= 5432
+
+  
+  
+  #            #
+  ##          ##
+  ### SQLITE ###
+  ##          ##
+  #            #
+
+
+# if postgres is used, just skip this section
+
+#
+## Db File
+#
+
+DB_FILE= '/my/sqlite/db/file'
