@@ -5,15 +5,19 @@
 #
 
 """
-Where the main Mother Classes are defined:
+Where the main Mother Classes and methods are defined:
 
+ * init_mother
  * DbMother
  * MotherManager
  * MotherBox
+ * MotherSession
+ * MotherPoolStatus
+ * MotherPoolStratus
 """
             
 from commons import ERR_COL, INF_COL, OKI_COL
-from dbda import Psygres
+from abdbda import DbOne, MoFilter
 
 #
 ##
@@ -39,14 +43,8 @@ MO_AFTER  = 1     # After?!?
 ## MoThEr: SQL symbols.
 #
 
-SQL_DEFAULT = "MOTHER_SQL_DEFAULT"
-SQL_NULL    =  None
-SQL_TRUE    = "True"
-SQL_FALSE   = "False"
-
-
-_J= ', '.join
-_A= ' AND '.join
+from abdbda import SQL_DEFAULT, SQL_NULL, SQL_TRUE, SQL_FALSE
+from abdbda import _J, _A
 
 #
 ##
@@ -54,16 +52,13 @@ _A= ' AND '.join
 ##
 #
 
-def init_mother(cfile, pg_conn= None, fnaming= None):
-    """ init_mother(cfile [,pg_conn= None, fnaming= None]) -> None
+def init_mother(cfile, fnaming= None):
+    """ init_mother(cfile [fnaming= None]) -> None
 
     Mother Initialization.
     `cfile` is the Mother configuration file. You can obtain a 
     default configuration file using mothermapper (option -C).
 
-    With pg_conn, you can pass your own psycopg connection. 
-    Don't do it, unless you have a very good reason.
-
     `fnaming` is a function: auto created methods will be named
     with this function. If None, a default function will be used.
 
@@ -84,32 +79,36 @@ def init_mother(cfile, pg_conn= None, fnaming= None):
 
     d= {}
     import speaker
-    import dbda
+    import abdbda
     names_dict= speaker.__dict__.copy()
-    names_dict.update(dbda.__dict__)
+    names_dict.update(abdbda.__dict__)
     execfile(cfile, names_dict, d)
 
-    # Handle OIDs or not?
-    use_oids= d.get('MOTHER_OIDS', True)
-    if not use_oids:
-        #from dbda import PsygresFly
-        del DbMother._sqlPkeysFromOid
-        dbda.PsygresFly.exported_methods.remove('lastrowid')
-        _sqli= DbMother._sqlInsertNoOid
-        _i= DbMother._insertNoOid
+    from abdbda import DB_ENGINE_PGRES
+    db_engine= d.get('DB_ENGINE', DB_ENGINE_PGRES)
+    if db_engine == DB_ENGINE_PGRES:
+        DbMother._sqlInsert= DbMother._sqlPostgresInsert
+        DbMother._mo_arg_format= '%%(%s)s'
+
+        use_oids= d.get('MOTHER_OIDS', True)
+        if not use_oids:
+            DbMother._mo_pg_oids= False
+            abdbda.DbFly.exported_methods.remove('lastrowid')
+        else:
+            DbMother._mo_pg_oids= True
+
     else:
-        _sqli= DbMother._sqlInsertOid
-        _i= DbMother._insertOid
+        DbMother._sqlInsert= DbMother._sqlSqliteInsert
+        DbMother._mo_arg_format= ':%s'
 
-    sname= d.get('MOTHER_SESSION_NAME', DbMother._mo_session_name)
+    del DB_ENGINE_PGRES
 
-    #from dbda import init_dbda
-
-    speaker.init_speaker(d)
-    dbda.init_dbda(d, pg_conn)
+    sname= d.get('MOTHER_SESSION_NAME', 
+            DbMother._mo_session_name)
+    abdbda.init_abdbda(d)
 
     del speaker
-    del dbda
+    del abdbda
 
     # Load DB map
     momap= d['MOTHER_MAP']
@@ -124,7 +123,7 @@ def init_mother(cfile, pg_conn= None, fnaming= None):
             assert isinstance(res_str, str)
         except:
             Speaker.log_warning(
-                    "Testing %s Default fnaming function "
+                    "Testing %s. Default fnaming function "
                     "will be used.", RED('Failed!'))
             fnaming= None
     
@@ -134,22 +133,16 @@ def init_mother(cfile, pg_conn= None, fnaming= None):
 
     DbMother.MotherNaming= staticmethod(fnaming)
     DbMother._mo_cfile= cfile
-    DbMother._oided_mother= use_oids
     DbMother.__init__= DbMother.__post_init__
-    DbMother._sqlInsert= _sqli
-    DbMother._insert= _i
     DbMother._mo_session_name= sname
 
     # Ohhh, destroying is amazing, isn't it?
     del DbMother.__post_init__
-    del DbMother._sqlInsertOid
-    del DbMother._sqlInsertNoOid
-    del DbMother._insertOid
-    del DbMother._insertNoOid
     del DbMother._mo_initialized
+    del DbMother._sqlSqliteInsert
+    del DbMother._sqlPostgresInsert
 
-
-def MotherSession(name= None, pg_conn= None):
+def MotherSession(name= None):
     """ MotherSession([name= None, pg_conn= None]) 
 
     Returns a new Session. Each session is an isolated unit of work.
@@ -158,13 +151,13 @@ def MotherSession(name= None, pg_conn= None):
     session.endSession(). This call commit the queries and, if the Mother
     Pool is used, put the connection inside the pool. """
 
-    from dbda import PsygresPool
+    from abdbda import MotherPool
 
     if not name:
         import random
         name= "%s%d" % (DbMother._mo_session_name, random.randint(1,10000))
 
-    return PsygresPool.newSession(name, pg_conn) 
+    return MotherPool.newSession(name) 
 
 def MotherPoolStatus():
     """MotherPoolStatus() -> (pool_type, avail, total, min, max, active)
@@ -176,11 +169,11 @@ def MotherPoolStatus():
     max: maximum number of connections allowed on the Pool.
     active: number of connections used now."""
 
-    from dbda import PsygresPool
+    from abdbda import MotherPool
 
-    if not PsygresPool._pool_initialized:
+    if not MotherPool._pool_initialized:
         return ('NoPool', -1, -1, -1, -1, -1)
-    return PsygresPool.status()
+    return MotherPool.status()
 
 def MotherPoolStratus():
     """ MotherPoolStratus() -> string
@@ -197,7 +190,7 @@ def MotherPoolStratus():
     Connections Employed    ~ %s 
     """ % MotherPoolStatus()
 
-class _DbMap(Psygres):
+class _DbMap(DbOne):
     _map_file=       None
     _map_fields=     None
     _map_pkeys=      None
@@ -293,11 +286,13 @@ class DbMother(_DbMap):
     """ The Holy MoThEr 
         An abstract class which represents a db Table.
     """
+    _mo_arg_format= None
     _mo_initialized= False
     _mo_cfile= None
     _mo_false_values= [SQL_NULL, SQL_DEFAULT]
     _mo_fuck= " MoThEr fucker!"
     _mo_session_name= "MoSession-"
+    _mo_pg_oids= False
     _mo_flags= { 
             MO_NOA: 'MO_NOA', 
             MO_DEL: 'MO_DEL', 
@@ -345,8 +340,9 @@ class DbMother(_DbMap):
 
         # Session() ?
         if session:
-            session._import(self)
-        elif not Psygres._db_initialized:
+            session._export_iface(self)
+
+        elif not DbOne._db_initialized:
             err= ERR_COL('!!!No Session Available!!!')
             self.log_int_raise("%s You are using the Db Pool, you "
                                "have disabled the persistent connection, "
@@ -354,6 +350,9 @@ class DbMother(_DbMap):
                                "Mother class (table= %s)", err, ERR_COL(tbl))
         self.session= session
 
+        if hasattr(self._iface_instance, '_mogrify'):
+            self.mogrify= self._iface_instance._mogrify
+
         # self.fields is a list with TABLE fields.
         # self.pkeys is a list with primary keys for the TABLE.
         # You can set these vars in the child class or let
@@ -411,6 +410,16 @@ class DbMother(_DbMap):
 
         self._flag_actions(self, flag)()
 
+    def _paranoid(self):
+        return getattr(self, 'paranoid', False)
+
+    def setParanoia(self):
+        setattr(self, 'paranoid', 1)
+
+    def unserParanoia(self):
+        setattr(self, 'paranoid', 0)
+        
+
 #
 ##
 ### Internal Core
@@ -419,6 +428,10 @@ class DbMother(_DbMap):
     def _triggers_are_initialized(self):
         return hasattr(self, 'triggers_map')
 
+    def _arg_format(self, k):
+        f= DbMother._mo_arg_format
+        return f % k
+
     def _unvaluedPKeys(self):
         """ _unvaluedPKeys() --> set
 
@@ -433,13 +446,6 @@ class DbMother(_DbMap):
             if not s.has_key(k)     \
             or s[k] in self._mo_false_values])
 
-    def _noPKeyFields(self):
-        """ _noPKeyFields() --> set
-
-        Returns the list of fields in store that are not pkeys.
-        """
-        return set(self._store.keys()) - self.pkeys
-
     def _invalidFields(self,fields):
         """ _invalidFields(fields) --> set
 
@@ -476,159 +482,176 @@ class DbMother(_DbMap):
 ##
 #
 
-    def _sqlPkeysFromOid(self, oid):
-        if not len(self.pkeys):
-            return
-        qry= self._sqlSelect(self.pkeys, 'oid= %d' % oid)
-        res= self.or_query(qry)
-        self._store.update(res)
-
-    def _sqlWherePkeys(self, params= None):
-        res= []
-
-        params= params and set(params) or set()
-        _s= self._store
-        _m= self._mo_false_values
-
-        for k in self.pkeys | params:
-
-            # If the field has a no-value (NULL or DEFAULT)
-            # it's excluded from the filter
-            v= _s[k]
-            if v == SQL_DEFAULT:
-                continue
-            if v == SQL_NULL:
-                res.append('%s IS NULL' % k)
-            else:
-                res.append('%s= %%(%s)s' % (k, k))
-
-        res= _A(res)
-        return self._sqlMogrify(res)
-
-    def _sqlUpdate(self, d, params= None):
+    def _sqlUpdate(self, d):
 
         res= []
         s= self._store
-
+        tbl= self.table_name
+        af= self._arg_format
         for k in d:
-            v= s[k]
+            v= s.get(k, SQL_DEFAULT)
+
             if v== SQL_DEFAULT:
-                res.append('%s= DEFAULT' % k)
+                res.append('%s= DEFAULT' %  k)
+
+            elif v == SQL_DEFAULT:
+                res.append('%s = NULL' %  k)
+
             else:
-                res.append('%s= %%(%s)s' % (k, k))
+                res.append('%s= %s' % (k, af(k)))
 
-        qry= ("UPDATE %s SET %s WHERE %s" % (self.table_name, 
-                _J(res), self._sqlWherePkeys(params)))
+        pk= self.pkeys
 
-        return self.mogrify(qry, s)
+        qry= 'UPDATE %s SET %s' % (self.table_name, _J(res))
 
-    def _sqlInsertNoOid(self, d):
+        # table without a pkey
+        if not pk:
+            ftr_keys= [k for k in self._store if k not in d]
+            if not ftr_keys:
+                self.log_int_raise('There is no key to build '
+                                   'the WHERE statement.')
+            ftr= MoFilter(ftr_keys, tbl, s)
+            self.oc_query(qry, ftr)
+            return 
+
+        # table with pkey
+        upk= self._unvaluedPKeys()
+        if not upk:
+            ftr= MoFilter(self.pkeys, tbl, s)
+            self.oc_query(qry, ftr)
+            return 
+
+        if self._paranoid():
+            self.log_int_raise('%s: writing-queries are forbidded '
+                               'without the primary key', 
+                                ERR_COL('Paranoid Mother Class'))
+        ftr_keys= [k for k in self._store if k not in d]
+        if not ftr_keys:
+            self.log_int_raise('There is no key to build '
+                               'the WHERE statement.')
+        ftr= MoFilter(ftr_keys, tbl, s)
+        self.oc_query(qry, ftr)
+        return 
+
+    def _sqlInsertCommon(self):
 
         s= self._store
 
         res= []
-        for k in d:
-            v= s[k]
+        for k, v in s.iteritems():
+
             if v== SQL_DEFAULT:
                 res.append('DEFAULT')
+            if v== SQL_NULL:
+                res.append('NULL')
             else:
-                res.append('%%(%s)s' % k)
+                res.append('%s' % self._arg_format(k))
 
         qry= ("INSERT INTO %s (%s) VALUES (%s) " % 
-                (self.table_name, _J(d), _J(res)))
+                (self.table_name, _J(s), _J(res)))
 
-        if len(self.pkeys):
-            qry+="RETURNING %s" % _J(self.pkeys)
+        return qry
 
-        return self._sqlMogrify(qry)
+    def _sqlPostgresInsert(self):
 
-    def _sqlInsertOid(self, d):
+        qry= self._sqlInsertCommon()
+        pk= self.pkeys
+        upk= pk and self._unvaluedPKeys() or None
+        ftr= self._store
+        if not len(pk) or not upk:
+            self.oc_query(qry, ftr)
+            return
 
-        s= self._store
+        # we need to recover the pkey
+        if not self._mo_pg_oids:
+            qry+= 'RETURNING %s' % _J(upk)
+            res= self.or_query(qry, ftr)
+            self._store.update(res)
+            return
 
-        res= []
-        for k in d:
-            v= s[k]
-            if v== SQL_DEFAULT:
-                res.append('DEFAULT')
-            else:
-                res.append('%%(%s)s' % k)
+        self.oc_query(qry, ftr)
+        oid= self.lastrowid()
+        res= self.or_query(
+                'SELECT (%s) FROM %s WHERE '
+                'oid= %d' % (_J(upk), 
+                self.table_name, oid))
 
-        qry= ("INSERT INTO %s (%s) VALUES (%s)" % 
-                (self.table_name, _J(d), _J(res)))
+        self._store.update(res)
+        return
 
-        return self._sqlMogrify(qry)
+    def _sqlSqliteInsert(self):
+
+        qry= self._sqlInsertCommon()
+        pk= self.pkeys
+        upk= pk and self._unvaluedPKeys() or None
+        ftr= self._store
+        if not len(pk) or not upk:
+            self.oc_query(qry, ftr)
+            return
+
+        # we need to recover the pkey
+        self.oc_query(qry, ftr)
+        oid= self.lastrowid()
+        res= self.or_query(
+                'SELECT (%s) FROM %s WHERE '
+                'oid= %d' % (_J(upk), 
+                self.table_name, oid))
+
+        self._store.update(res)
+        return
+
+    def _sqlInsert(self):
+        self.log_int_raise(
+                ERR_COL('!!! Mother Not Initialized !!!'))
 
     def _sqlDelete(self, params= None):
 
-        filter= self._sqlWherePkeys(params)
-        return ("DELETE FROM %s WHERE %s" % 
-                (self.table_name, filter))
+        pk= self.pkeys
+        if not pk:
+            if not len(self._store):
+                self.log_int_raise('There is no key to build '
+                                   'the WHERE statement.')
+            ftr= MoFilter(self._store, self.table_name)
+            self.oc_query('DELETE FROM %s' % 
+                    self.table_name, ftr)
+            return
 
-    def _sqlSelect(self, d, filter= None, tbl= None):
+        upk= self._unvaluedPKeys()
+        if not upk:
+            ftr= MoFilter(pk, self.table_name, self._store)
+            self.oc_query('DELETE FROM %s' %
+                    self.table_name, ftr)
+            return
 
-        if filter is None:
-            filter= self._sqlWherePkeys()
+        if self._paranoid():
+            self.log_int_raise(ERR_COL('Paranoid Mother Class: '
+                               'writing-queries are forbidded '
+                               'without the primary key'))
 
-        tbl= tbl or self.table_name
+        if not len(self._store):
+            self.log_int_raise('There is no key to build '
+                               'the WHERE statement.')
+        ftr= MoFilter(self._store, self.table_name)
+        self.oc_query('DELETE FROM %s' %
+                self.table_name, ftr)
+        return
+
+    def _sqlSelect(self, d):
+
+        s= self._store
+        if not len(s):
+            self.log_int_raise('There is no key to build '
+                               'the WHERE statement.')
+
+        tbl= self.table_name
+        ftr= MoFilter(self._store, self.table_name)
+        d= d or self.fields
         what= ['%s.%s' % (tbl, f) for f in d]
 
-        return ("SELECT %s FROM %s WHERE %s" % 
-                (_J(what), tbl, filter ))
-
-
-    def _sqlBuildFilter(self, filter, prefix= False, tbl= None):
-        """ _sqlBuildFilter(self, filter [,prefix, tbl]) --> str
-
-        Build the filter as SQL string. filter could be
-        a string, a dict or a list (in such case use internal store).
-        If prefix, WHERE is added (unless it's present yet).
-        With tbl you can specify where apply the filter.
-        """
-
-        def t(tp):
-            return isinstance(filter, tp)
-
-        tbl= tbl or self.table_name
-
-        if t(str):
-            s= filter
-
-        elif t(dict):
-            res= []
-            for k, v in filter.iteritems():
-                if v== SQL_DEFAULT:
-                    res.append('%s.%s= DEFAULT' % (tbl, k))
-                else:
-                    res.append('%s.%s= %%(%s)s' % (tbl, k, k))
-            s= self.mogrify(_A(res), filter)
-
-        elif t(set) or t(frozenset) or t(list):
-            res= []
-            for k in filter:
-                v= self._store[k]
-                if v== SQL_DEFAULT:
-                    res.append('%s.%s= DEFAULT' % (tbl, k))
-                else:
-                    res.append('%s.%s= %%(%s)s' % (tbl, k, k))
-            s=self._sqlMogrify(_A(res))
-
-        else:
-            self.log_int_raise(\
-                    "Invalid filter type: %s.",\
-                    ERR_COL(str(filter)))
-
-        # Prevent Double WHERE
-        if not prefix or 'WHERE' in s:
-            return s
-
-        return " WHERE %s " % s 
-
-    def _sqlMogrify(self, s, d= None):
-        """ A wrapper to dbda.mogrify that take
-        self._store as default dict value.
-        """
-        return self.mogrify(s, d or self._store)
+        res= self.or_query("SELECT %s FROM %s " % 
+                (_J(what), tbl), ftr)
+        self._store.update(res)
+        return
 
 #
 ##
@@ -757,13 +780,13 @@ class DbMother(_DbMap):
         # If you want to load a different record, use refresh()
         if field_name in self.pkeys:
             self.log_int_raise(
-                " Safe behaviour: you can not change Pkeys Value. "\
-                "Want to load a new record? Use refresh() "\
+                " Safe behaviour: you can not change Pkeys Value. "
+                "Want to load a new record? Use refresh() "
                 "Want to update a Pkey? Create new and delete old."
                 )
 
         if field_name not in self.fields:
-            self.log_int_raise("Mth: cannot setField(): field "\
+            self.log_int_raise("Mth: cannot setField(): field "
                     "%s is invalid.",ERR_COL(field_name))
 
         # Ok, new value is good
@@ -784,7 +807,7 @@ class DbMother(_DbMap):
         new_fields=set(fdict.keys())
         onzo= self._invalidFields(new_fields)
         if onzo:
-            self.log_int_raise("Mth: cannot setFields(): "\
+            self.log_int_raise("Mth: cannot setFields(): "
                     "invalid fields %s.", ERR_COL(str(onzo)))
 
         # Cannot change pkeys
@@ -815,6 +838,10 @@ class DbMother(_DbMap):
         if field in self._store:
             return self._store[field]
 
+        if field not in self.fields:
+            self.log_int_raise('Invalid field %s for table |%s|', 
+                    ERR_COL(field), ERR_COL(self.table_name))
+
         if not autoload:
             self.log_int_raise("Mth: field %s is not valued: use autoload= True "
                                "to load it automatically from the table |%s|.",
@@ -823,7 +850,7 @@ class DbMother(_DbMap):
         lfield= [field]
         onzo= self._invalidFields(lfield)
         if onzo:
-            self.log_int_raise("Mth: cannot getField(): "\
+            self.log_int_raise("Mth: cannot getField(): "
                                "invalid field %s for table |%s|", 
                                 ERR_COL(str(field)), ERR_COL(self.table_name))
 
@@ -846,88 +873,41 @@ class DbMother(_DbMap):
 
         onzo= self._invalidFields(fields)
         if onzo:
-            self.log_int_raise("Mth: cannot getFields(): "\
+            self.log_int_raise("Mth: cannot getFields(): "
                     "invalid fields %s.", ERR_COL(str(onzo)))
-        newd={}
+        newd= {}
         if autoload:
-            skeys=set(self._store.keys())
-            nkeys=set(fields)
-            lkeys=nkeys-skeys
+            skeys= set(self._store.keys())
+            nkeys= set(fields)
+            lkeys= nkeys - skeys
             if len(lkeys):
                 self.log_insane("Autoloading fields %s...", INF_COL(lkeys))
                 self.load(lkeys)
             
         for f in fields:
             try:
-                val=self._store[f]
-                newd[f]=val
+                val= self._store[f]
+                newd[f]= val
             except:
-                self.log_int_raise(\
-                    "Mth: field %s is not valued.",\
+                self.log_int_raise(
+                    "Mth: field %s is not valued.",
                         ERR_COL(f))
         return newd
 
-    def _insertOid(self):
+    def _insert(self):
 
-        s= self._store
-
-        # Useful vars
-        sk= s.keys()
-
-        # Make the query ...
-        qry= self._sqlInsert(sk)
-
-        # ... and execute it
-        self.oc_query(qry)
-
-        # get last oid (for INSERT only)
-        oid= self.lastrowid()
-        self._sqlPkeysFromOid(oid)
-
-        # Nothing has to be updated now.
-        self._moved.clear()
-
-    def _insertNoOid(self):
-
-        s= self._store
-
-        # Useful vars
-        sk= s.keys()
-
-        # Make the query ...
-        qry= self._sqlInsert(sk)
-
-        if len(self.pkeys):
-            res= self.or_query(qry)
-            self._store.update(res)
-        else:
-            self.oc_query(qry)
-
-        # Nothing has to be updated now.
+        qry= self._sqlInsert()
         self._moved.clear()
 
     def _update(self):
 
         # Really need to update?
         if not self._moved:
-            self.log_int_raise("Mth: nothing to update.")
+            self.log_info("nothing to update.")
+            return
 
-        ange= self._unvaluedPKeys()
-        if ange:
-            from eccez import UpdateError
-            self.log_raise("Refusing to UPDATE record "\
-                           "without primary key (missing %s).",
-                           ERR_COL(list(ange)), UpdateError)
+        qry= self._sqlUpdate(self._moved)
 
-        params= (set(self._store) - set(self._moved)) 
-
-        # Make the query ...
-        qry= self._sqlUpdate(self._moved, params)
-
-        # and execute it
-        self.oc_query(qry)
-
-        # Debugging infos...
         self.log_insane( "Mth: fields %s moved ;)",
                 OKI_COL(self._moved))
 
@@ -936,32 +916,13 @@ class DbMother(_DbMap):
 
     def _delete(self):
 
-        # The values in store act as filters
-        # when deleting
-        ange= self._unvaluedPKeys()
-        if ange:
-            from eccez import DeleteError
-            self.log_raise("Refusing to DELETE record "\
-                           "without primary key (missing %s).",
-                           ERR_COL(list(ange)), DeleteError)
-
-        # the store acts as a filter..
-        params= set(self._store.keys())
-        #_i= self._store.iteritems
-        #params= set([k for k, v in _i() if v 
-        #             not in self._mo_false_values]
-
-        # Make the query ...
-        qry= self._sqlDelete(params)
-
-        # and execute it
-        self.oc_query(qry)
+        qry= self._sqlDelete()
 
         # Delete all informations...  
         self._moved.clear()
         self._store.clear()
 
-    def _load(self, fields= None, safe_mode= True):
+    def _load(self, fields= None):
 
         # Which fields we need?
         mf= fields and set(fields) or set(self._fieldsMissing())
@@ -973,35 +934,16 @@ class DbMother(_DbMap):
                     self.table_name, SelectError)
 
         if not len(mf):
-            self.log_warning("No fields specified for SELECT: table %s",
+            self.log_warning("No field has to be SELECTed: table %s",
                         ERR_COL(self.table_name))
             return self.getFields()
 
-        if safe_mode:
-            ange= self._unvaluedPKeys()
-            if ange:
-                from eccez import SelectError
-                self.log_raise("Refusing to LOAD record "\
-                               "without primary key (missing %s). "
-                               "Use ULOAD to avoid this limit.",
-                               ERR_COL(list(ange)), SelectError)
+        qry= self._sqlSelect(mf)
 
-        filter= self._sqlBuildFilter(self._store)
-
-        # Make the query ...
-        qry= self._sqlSelect(mf, filter= filter)
-
-        # and execute it
-        res= self.or_query(qry)
-
-        # Update values on store
-        self._store.update(res)
-
-        # Forgot old to-update fields  
         self._moved-= mf
 
         # Useful return, that's all
-        return res
+        return self.getFields()
 
     def _triggered_action(self, flag, *args):
 
@@ -1009,27 +951,12 @@ class DbMother(_DbMap):
 
         if not self._triggers_are_initialized() or \
            not self.get_flag_triggers(flag):
-
             res= f(*args)
-
         else:
             self._safeBeginTrans()
             try:
-                self.log_insane(
-                        "Launching %s triggers...",
-                        OKI_COL('before'))
                 self.trigger(flag, MO_BEFORE)
-
-                self.log_insane( 
-                        "Executing %s action...",
-                        OKI_COL(self._mo_flags[flag]))
-
                 res= f(*args)
-
-                self.log_insane( 
-                        "Launching %s triggers...",
-                        OKI_COL('after'))
-
                 self.trigger(flag, MO_AFTER)
 
             except Exception, s:
@@ -1048,16 +975,14 @@ class DbMother(_DbMap):
         """
         self._triggered_action(MO_DEL)
     
-    def load(self, fields= None, safe_mode= True):
-        """ load([fields= None, safe_mode= True]) --> dict
+    def load(self, fields= None):
+        """ load([fields= None]) --> dict
 
         Retrieve record values from DB. 
         if fields is not None, only fields specified will
         be loaded.
-        If safe_mode is False, try to load the record also if
-        primary keys was not given.
         """
-        return self._triggered_action(MO_LOAD,fields,safe_mode)
+        return self._triggered_action(MO_LOAD,fields)
 
     def insert(self):
         """ insert() --> None
@@ -1083,16 +1008,16 @@ class DbMother(_DbMap):
     def uload(self, fields= None):
         """ uload([fields= None]) --> dict
 
-        This is a call to load() with safe_mode= False
         """
-
-        return self.load(fields,safe_mode=False)
+        self.log_warning(ERR_COL("Obsolete action MO_ULOAD: from Mother "
+                         "0.6.0 MO_ULOAD and MO_LOAD are equivalent. "
+                         "MO_ULOAD will be dropped. Use MO_LOAD."))
+        return self.load(fields)
 
     def refresh(self, d, flag= MO_NOA):
         """ refresh(d[,flag=MO_NOA]) --> None
 
-        You can secify here a new set of pkeys and
-        have a new, fresh mother
+        Reinitialize this instance. The session is preserved. 
         """
         # init store.
         self._initStore(d, flag)
@@ -1171,18 +1096,19 @@ class MotherManager:
 #
 
     def _sqlJoin(self, j_tbl, r_tbl, j_key, r_key):
-        """ _sqlJoin(self, j_tbl, r_tbl, j_key, r_key) --> str\n 
+        """ _sqlJoin(self, j_tbl, r_tbl, j_key, r_key) --> str
 
         Returns the join query.
         """
 
-        s= " JOIN %s on " % r_tbl
-        s+=_A(\
+        s= "JOIN %s ON %s" % (r_tbl, 
+           _A(
             [" %s.%s = %s.%s " % (r_tbl,v,j_tbl,k)
-                for k,v in j_key.iteritems()])
+                for k,v in j_key.iteritems()]))
+
         s+=" WHERE "
-        s+=_A(\
-            ["%s.%s = %%(%s)s " % (r_tbl,v,k)\
+        s+=_A(
+            ["%s.%s = %%(%s)s " % (r_tbl,v,k)
                 for k,v in r_key.iteritems()])
 
         return s
@@ -1335,7 +1261,7 @@ class MotherManager:
         return self._workChild( 
                                 cbuilder,
                                 c_dict,
-                                MO_ULOAD,
+                                MO_LOAD,
                               )
                                     
 
@@ -1379,12 +1305,11 @@ class MotherManager:
         d= self.getChildDeps(child_table)
         d= self._getDepDict(d)
 
-        qry_filter= self._sqlBuildFilter(d, tbl=child_table)
-        if filter is not None:
-            qry_filter+= " AND %s" % \
-                    self._sqlBuildFilter(filter, tbl=child_table)
+        ftr= MoFilter(d, child_table)
+        if filter:
+            ftr.add_filter(filter, child_table) 
 
-        MotherBox(cbuilder, qry_filter, MO_DEL)
+        MotherBox(cbuilder, ftr, MO_DEL, session= self.session)
 
     def updateChildren(self, cbuilder, d_up, filter= None):
         """ updateChildren(self, cbuilder, d_up [, filter= None]) --> None
@@ -1398,13 +1323,12 @@ class MotherManager:
         d= self._getDepDict(d)
 
         # Build filter
-        qry_filter= self._sqlBuildFilter(d, tbl=child_table)
+        ftr= MoFilter(d, child_table)
         if filter is not None:
-            qry_filter+= " AND %s" % \
-                    self._sqlBuildFilter(filter, tbl=child_table)
+            ftr.add_filter(filter, child_table) 
 
         MotherBox(cbuilder, flag=MO_UP, fields= d_up, 
-                filter= qry_filter, session= self.session) 
+                filter= ftr, session= self.session) 
 
     def getChildren(self, cbuilder, fields= None, filter= None,\
                     jbuilder= None, jfilter= None,
@@ -1432,29 +1356,27 @@ class MotherManager:
                 ('', '')
 
         # Build SQL filter string
-        qry_filter+= " WHERE "
+        tbl= joining_table or None
+        ftr= MoFilter(qry_filter, tbl= tbl)
 
         # now filter father dependencies
-        qry_filter+= self._sqlBuildFilter(d, tbl= child_table)
+        ftr.add_filter(d, child_table)
 
         # Filter join condition
         # Note that the filter is used on the joined table
         # that is returned by _sqlJoinParent
         if jbuilder and jfilter:
-            qry_filter+=" AND %s " %\
-                self._sqlBuildFilter(\
-                jfilter, tbl= joining_table)
+            ftr.add_filter(jfilter, joining_table)
 
         # if filter is specified, use it ...
         # the filter `filter` is used on Child Table.
         if filter is not None:
-            qry_filter+=" AND  %s " %\
-                self._sqlBuildFilter(filter,tbl=child_table)
+            ftr.add_filter(filter, child_table)
 
         # Let's use a MotherBox :)
         # If join use DISTINCT
         distinct= (jbuilder is not None)
-        mb= MotherBox(cbuilder, filter= qry_filter, flag= MO_LOAD,
+        mb= MotherBox(cbuilder, filter= ftr, flag= MO_LOAD,
                         fields= fields, order= order, distinct= distinct, 
                         session= self.session)
         # Oh yes, return ;)
@@ -1633,23 +1555,23 @@ class MotherManager:
         if fields== []:
             fields= self._table_fields(b_tbl)
 
-        self.log_insane("Joining %s and %s with relation %s "\
-                        "and fields %s ...",s_tbl,b_tbl,\
+        self.log_insane("Joining %s and %s with relation %s "
+                        "and fields %s ...",s_tbl,b_tbl,
                         INF_COL(r_tbl),INF_COL(str(fields)))
                         
         # Make the base filter query ...
         qry_filter = self._sqlJoin(b_tbl, r_tbl, b_d, s_d)
+        ftr= MoFilter(qry_filter, store= self._store)
 
         # If filters are given, apply it.
         if filter:
-            qry_filter+=" AND %s " % self._sqlBuildFilter(filter, tbl= r_tbl)
+            ftr.add_filter(filter, r_tbl)
         if jfilter:
-            qry_filter+=" AND %s " % self._sqlBuildFilter(jfilter, tbl= b_tbl)
-        # Mogrify the obtained filter query ...
-        qry_filter= self._sqlMogrify(qry_filter)
+            ftr.add_filter(jfilter, b_tbl)
 
         # get a MotherBox
-        mb= MotherBox(builder, qry_filter, MO_LOAD, fields, order, session= self.session)
+        mb= MotherBox(builder, ftr, MO_LOAD, fields, order, 
+                    distinct= 1, session= self.session)
         return mb
 
     def relParams(self, related, fields= None, flag_obj= False):
@@ -1928,13 +1850,13 @@ class MotherManager:
 ##
 #
 
-class MotherBox(Psygres):
+class MotherBox(DbOne):
     def __init__(self, builder, filter= None, flag= MO_NOA, 
                     fields= None, order= None, session= None, 
                     distinct= False, notriggers= False):
 
         if session:
-            session._import(self)
+            session._export_iface(self)
 
         self.session= session
         self.builder= builder
@@ -1942,9 +1864,10 @@ class MotherBox(Psygres):
         self.notriggers= notriggers
     
         if filter:
-            filter= self.momma._sqlBuildFilter(filter, True)
+            if not isinstance(filter, MoFilter):
+                filter= MoFilter(filter)
         else:
-            filter= ''
+            filter= MoFilter()
 
         self._store= []
 
@@ -1995,18 +1918,9 @@ class MotherBox(Psygres):
 
         tbl= self.builder.table_name
 
-        self.log_insane(
-                "Mbox: loading with filter=%s",\
-                INF_COL(filter))
-
         distinct= distinct and 'DISTINCT' or ''
 
-        sel="SELECT %(distinct)s %(what)s FROM %(tbl)s %(filter)s "
-
-        if filter:
-            filter= self.momma._sqlBuildFilter(filter, prefix= True)
-        else:
-            filter= ''
+        sel="SELECT %(distinct)s %(what)s FROM %(tbl)s "
 
         if fields is None:
             what= _J(['%s.%s' % (tbl, f) for f in self.momma.fields])
@@ -2020,9 +1934,9 @@ class MotherBox(Psygres):
         qry= sel % locals()
 
         if order:
-            qry+= " ORDER BY %s" % _J(order)
+            filter.add_post("ORDER BY %s" % _J(order))
 
-        self._store= self.mr_query(qry)
+        self._store= self.mr_query(qry, filter)
 
         self.log_debug("Loaded %s records on %s",\
                 OKI_COL(len(self._store)), tbl)
@@ -2062,25 +1976,25 @@ class MotherBox(Psygres):
 
         table= self.builder.table_name
 
-        if filter:
-            ftr= self.momma._sqlBuildFilter(filter, prefix= True)
-        else:
-            ftr= ''
-
         res= []
         for k, v in d.iteritems():
             if v== SQL_DEFAULT:
                 res.append('%s= DEFAULT' % k)
+            if v== SQL_DEFAULT:
+                res.append('%s= NULL' % k)
             else:
-                res.append('%s= %%(%s)s' % (k, k))
+                res.append('%s= %s' % (k, self.momma._arg_format(k)))
+
+        if not filter:
+            filter= MoFilter()
+        filter.add_store(d)
 
         what= _J(res)
         tbl= self.builder.table_name
 
-        qry= 'UPDATE %(tbl)s SET %(what)s %(ftr)s' % locals()
-        qry= self.mogrify(qry, d)
+        qry= 'UPDATE %(tbl)s SET %(what)s ' % locals()
 
-        self.oc_query(qry)
+        self.oc_query(qry, filter)
         self.log_insane("Box: Updatetd records.")
 
         self.log_info("Action %s.", OKI_COL("completed"))
@@ -2107,13 +2021,8 @@ class MotherBox(Psygres):
         self.log_insane("Mbox: deleting with filter=%s", INF_COL(filter))
 
         tbl= self.builder.table_name
-        if filter:
-            filter= self.momma._sqlBuildFilter(filter, prefix= True)
-        else:
-            filter= ''
 
-        qry="DELETE FROM %(tbl)s %(filter)s" % locals()
-        self.oc_query(qry)
+        self.oc_query('DELETE FROM %s' % tbl, filter)
         self.log_insane("Records deleted.")
 
         self.log_info("Action %s.", OKI_COL("completed"))
